@@ -145,7 +145,7 @@ def parse_point(point):
     For example, "10,20" returns (10.0, 20.0).
 
     Args:
-        point (str): Parseable str of latitude and longitude.
+        point (str): Parsable str of latitude and longitude.
 
     Returns:
         float, float: Parsed latitude and longitude in decimal degrees.
@@ -164,7 +164,7 @@ def parse_point(point):
     elif typ in (list, tuple) and len(point) == 2:
         lat = get_float(point[0])
         lon = get_float(point[1])
-    return lat, lon
+    return [lat, lon]
 
 
 def parse_bbox(bbox):
@@ -178,7 +178,7 @@ def parse_bbox(bbox):
     For example, "10,20,30,40" returns (10.0, 20.0, 30.0, 40.0).
 
     Args:
-        bbox (str): Parseable str of south, north, west, and east.
+        bbox (str): Parsable str of south, north, west, and east.
 
     Returns:
         float, float, float, float: South, north, west, and east in decimal
@@ -205,7 +205,7 @@ def parse_bbox(bbox):
         n = get_float(bbox[1])
         w = get_float(bbox[2])
         e = get_float(bbox[3])
-    return s, n, w, e
+    return [s, n, w, e]
 
 
 ################################################################################
@@ -217,7 +217,7 @@ def calc_poly_bbox(poly):
     west, and east floats in decimal degrees.
 
     Args:
-        poly (list): List of parseable point geometries. See parse_poly().
+        poly (list): List of parsable point geometries. See parse_poly().
 
     Returns:
         float, float, float, float: South, north, west, and east in decimal
@@ -317,10 +317,13 @@ def is_bbox_within_bbox(bbox1, bbox2):
 
 def query_point_using_cursor(
         projpicker_cur,
-        point):
+        point,
+        unit="any",
+        negate=False):
     """
-    Return a list of BBox instances that completely contain an input point
-    geometry defined by latitude and longitude in decimal degrees. Each BBox
+    Return a list of BBox instances in unit that completely contain an input
+    point geometry defined by latitude and longitude in decimal degrees. Use
+    the negate argument to return non-containing BBox instances. Each BBox
     instance is a named tuple with all the columns from the bbox table in
     projpicker.db. This function is used to perform a union operation on BBox
     instances consecutively. Results are sorted by area from the smallest to
@@ -329,8 +332,10 @@ def query_point_using_cursor(
     Args:
         projpicker_cur (sqlite3.Cursor): projpicker.db cursor.
         point (list or str): List of latitude and longitude floats in decimal
-            degrees or parseable str of latitude and longitude. See
+            degrees or parsable str of latitude and longitude. See
             parse_point().
+        unit (str): "any", unit values from projpicker.db.
+        negate (bool): Whether or not to negate query. Defaults to False.
 
     Returns:
         list: List of queried BBox instances sorted by area.
@@ -343,16 +348,26 @@ def query_point_using_cursor(
     # if west_lon >= east_lon, bbox crosses the antimeridian
     sql = f"""SELECT *
               FROM bbox
-              WHERE {lat} BETWEEN south_lat AND north_lat AND
-                    (west_lon = east_lon OR
-                     (west_lon = -180 AND east_lon = 180) OR
-                     (west_lon < east_lon AND
-                      {lon} BETWEEN west_lon AND east_lon) OR
-                     (west_lon > east_lon AND
-                      ({lon} BETWEEN -180 AND east_lon OR
-                       {lon} BETWEEN west_lon AND 180)))
-              ORDER BY area_sqkm"""
-    projpicker_cur.execute(sql)
+              WHERE {"NOT" if negate else ""}
+                    ({lat} BETWEEN south_lat AND north_lat AND
+                     (west_lon = east_lon OR
+                      (west_lon = -180 AND east_lon = 180) OR
+                      (west_lon < east_lon AND
+                       {lon} BETWEEN west_lon AND east_lon) OR
+                      (west_lon > east_lon AND
+                       ({lon} BETWEEN -180 AND east_lon OR
+                        {lon} BETWEEN west_lon AND 180))) AND_UNIT)
+              ORDER BY area_sqkm,
+                       proj_table,
+                       crs_auth_name, crs_code,
+                       usage_auth_name, usage_code,
+                       extent_auth_name, extent_code"""
+    if unit == "any":
+        sql = sql.replace("AND_UNIT", "")
+        projpicker_cur.execute(sql)
+    else:
+        sql = sql.replace("AND_UNIT", "AND unit = ?")
+        projpicker_cur.execute(sql, (unit,))
     for row in map(BBox._make, projpicker_cur.fetchall()):
         outbbox.append(row)
     return outbbox
@@ -360,10 +375,13 @@ def query_point_using_cursor(
 
 def query_bbox_using_cursor(
         projpicker_cur,
-        bbox):
+        bbox,
+        unit="any",
+        negate=False):
     """
-    Return a list of BBox instances that completely contain an input bbox
-    geometry defined by sout, north, west, and east using a database cursor.
+    Return a list of BBox instances in unit that completely contain an input
+    bbox geometry defined by sout, north, west, and east using a database
+    cursor. Use the negate argument to return non-containing BBox instances.
     Each BBox instance is a named tuple with all the columns from the bbox
     table in projpicker.db. This function is used to perform a union operation
     on bbox rows consecutively. Results are sorted by area from the smallest to
@@ -372,8 +390,10 @@ def query_bbox_using_cursor(
     Args:
         projpicker_cur (sqlite3.Cursor): projpicker.db cursor.
         bbox (list or str): List of south, north, west, and east floats in
-            decimal degrees or parseable str of south, north, west, and east.
+            decimal degrees or parsable str of south, north, west, and east.
             See parse_bbox().
+        unit (str): "any", unit values from projpicker.db.
+        negate (bool): Whether or not to negate query. Defaults to False.
 
     Returns:
         list: List of queried BBox instances sorted by area.
@@ -386,25 +406,35 @@ def query_bbox_using_cursor(
     # if west_lon >= east_lon, bbox crosses the antimeridian
     sql = f"""SELECT *
               FROM bbox
-              WHERE {s} BETWEEN south_lat AND north_lat AND
-                    {n} BETWEEN south_lat AND north_lat AND
-                    (west_lon = east_lon OR
-                     (west_lon = -180 AND east_lon = 180) OR
-                     (west_lon < east_lon AND
-                      {w} <= {e} AND
-                      {w} BETWEEN west_lon AND east_lon AND
-                      {e} BETWEEN west_lon AND east_lon) OR
-                     (west_lon > east_lon AND
-                      (({w} <= {e} AND
-                        (({w} BETWEEN -180 AND east_lon AND
-                          {e} BETWEEN -180 AND east_lon) OR
-                         ({w} BETWEEN west_lon AND 180 AND
-                          {e} BETWEEN west_lon AND 180))) OR
-                       ({w} > {e} AND
-                        {e} BETWEEN -180 AND east_lon AND
-                        {w} BETWEEN west_lon AND 180))))
-              ORDER BY area_sqkm"""
-    projpicker_cur.execute(sql)
+              WHERE {"NOT" if negate else ""}
+                    ({s} BETWEEN south_lat AND north_lat AND
+                     {n} BETWEEN south_lat AND north_lat AND
+                     (west_lon = east_lon OR
+                      (west_lon = -180 AND east_lon = 180) OR
+                      (west_lon < east_lon AND
+                       {w} <= {e} AND
+                       {w} BETWEEN west_lon AND east_lon AND
+                       {e} BETWEEN west_lon AND east_lon) OR
+                      (west_lon > east_lon AND
+                       (({w} <= {e} AND
+                         (({w} BETWEEN -180 AND east_lon AND
+                           {e} BETWEEN -180 AND east_lon) OR
+                          ({w} BETWEEN west_lon AND 180 AND
+                           {e} BETWEEN west_lon AND 180))) OR
+                        ({w} > {e} AND
+                         {e} BETWEEN -180 AND east_lon AND
+                         {w} BETWEEN west_lon AND 180)))) AND_UNIT)
+              ORDER BY area_sqkm,
+                       proj_table,
+                       crs_auth_name, crs_code,
+                       usage_auth_name, usage_code,
+                       extent_auth_name, extent_code"""
+    if unit == "any":
+        sql = sql.replace("AND_UNIT", "")
+        projpicker_cur.execute(sql)
+    else:
+        sql = sql.replace("AND_UNIT", "AND unit = ?")
+        projpicker_cur.execute(sql, (unit,))
     for row in map(BBox._make, projpicker_cur.fetchall()):
         outbbox.append(row)
     return outbbox
